package com.sooka.system.service.impl;

import java.util.List;

import com.sooka.common.core.text.Convert;
import com.sooka.common.utils.DateUtils;
import com.sooka.common.utils.uuid.UUID;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.sooka.system.mapper.TUParamspublicMapper;
import com.sooka.system.domain.TUParamspublic;
import com.sooka.system.service.ITUParamspublicService;


/**
 * 公共请求参数Service业务层处理
 *
 * @author lei
 * @date 2021-07-01
 */
@Service
public class TUParamspublicServiceImpl implements ITUParamspublicService
{
    @Autowired
    private TUParamspublicMapper tUParamspublicMapper;

    /**
     * 查询公共请求参数
     *
     * @param id 公共请求参数ID
     * @return 公共请求参数
     */
    @Override
    public TUParamspublic selectTUParamspublicById(String id)
    {
        return tUParamspublicMapper.selectTUParamspublicById(id);
    }

    /**
     * 查询公共请求参数列表
     *
     * @param tUParamspublic 公共请求参数
     * @return 公共请求参数
     */
    @Override
    public List<TUParamspublic> selectTUParamspublicList(TUParamspublic tUParamspublic)
    {
        return tUParamspublicMapper.selectTUParamspublicList(tUParamspublic);
    }

    /**
     * 新增公共请求参数
     *
     * @param tUParamspublic 公共请求参数
     * @return 结果
     */
    @Override
    public int insertTUParamspublic(TUParamspublic tUParamspublic)
    {
        tUParamspublic.setId(UUID.fastUUID().toString());
        tUParamspublic.setCreateTime(DateUtils.getNowDate());
        return tUParamspublicMapper.insertTUParamspublic(tUParamspublic);
    }

    /**
     * 修改公共请求参数
     *
     * @param tUParamspublic 公共请求参数
     * @return 结果
     */
    @Override
    public int updateTUParamspublic(TUParamspublic tUParamspublic)
    {
        tUParamspublic.setUpdateTime(DateUtils.getNowDate());
        return tUParamspublicMapper.updateTUParamspublic(tUParamspublic);
    }

    /**
     * 删除公共请求参数对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTUParamspublicByIds(String ids)
    {
        return tUParamspublicMapper.deleteTUParamspublicByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除公共请求参数信息
     *
     * @param id 公共请求参数ID
     * @return 结果
     */
    @Override
    public int deleteTUParamspublicById(String id)
    {
        return tUParamspublicMapper.deleteTUParamspublicById(id);
    }
}
